



go env
IF %ERRORLEVEL% NEQ 0 exit /B 1
go build hello.go
IF %ERRORLEVEL% NEQ 0 exit /B 1
for /f "usebackq tokens=*" %%a in (`go env GOEXE`) do file hello%%a | grep 'ELF'
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
